# Groq Cloud API Key

Groq Cloud API Key allows you to have FREE access to [selected open source LLMs](https://console.groq.com/docs/models).

At the time of writing, use of Groq Cloud API is FREE.

# Generate Groq API Key

1. Go to https://console.groq.com/keys

2. Log in with a registered account

3. Click menu item "API Keys" on the left

4. Click button "Create API Key"

5. Enter a name, for example, "freegenius"

6. Copy or make a note of the created API key

![groq_api_key](https://github.com/eliranwong/freegenius/assets/25262722/d479ad5f-40b5-4d9b-a766-83db023ead1c)

# Set Up Groq API Key in FreeGenius

1. Enter ".apikeys" in FreeGenius AI prompt

2. Follow the dialog and enter your Groq API key